==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/GridSelectedCellsChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridSelectedCellsChangedEventArgsDescription } from "./GridSelectedCellsChangedEventArgsDescription";
/**
 * @hidden
 */
export let GridSelectedCellsChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridSelectedCellsChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (GridSelectedCellsChangedEventArgsDescriptionMetadata.a == null) {
                GridSelectedCellsChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridSelectedCellsChangedEventArgsDescriptionMetadata.c(GridSelectedCellsChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(GridSelectedCellsChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(GridSelectedCellsChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("CurrentCells", "Collection:CellKey:GridSelectedCellsCollection:CellKey");
            a.item("AddedCells", "Collection:CellKey:GridSelectedCellsCollection:CellKey");
            a.item("RemovedCells", "Collection:CellKey:GridSelectedCellsCollection:CellKey");
        }
        static d(a) {
            GridSelectedCellsChangedEventArgsDescriptionMetadata.b(a);
            a.ad("GridSelectedCellsChangedEventArgs", () => new GridSelectedCellsChangedEventArgsDescription());
            a.ac("GridSelectedCellsChangedEventArgs", GridSelectedCellsChangedEventArgsDescriptionMetadata.a);
        }
    }
    GridSelectedCellsChangedEventArgsDescriptionMetadata.$t = markType(GridSelectedCellsChangedEventArgsDescriptionMetadata, 'GridSelectedCellsChangedEventArgsDescriptionMetadata');
    GridSelectedCellsChangedEventArgsDescriptionMetadata.a = null;
    return GridSelectedCellsChangedEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/GridSelectedCellsChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridSelectedCellsChangedEventArgsDescription } from "./GridSelectedCellsChangedEventArgsDescription";
/**
 * @hidden
 */
export let GridSelectedCellsChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridSelectedCellsChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (GridSelectedCellsChangedEventArgsDescriptionMetadata.a == null) {
                GridSelectedCellsChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridSelectedCellsChangedEventArgsDescriptionMetadata.c(GridSelectedCellsChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(GridSelectedCellsChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(GridSelectedCellsChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("CurrentCells", "Collection:CellKey:GridSelectedCellsCollection:CellKey");
            a.item("AddedCells", "Collection:CellKey:GridSelectedCellsCollection:CellKey");
            a.item("RemovedCells", "Collection:CellKey:GridSelectedCellsCollection:CellKey");
        }
        static d(a) {
            GridSelectedCellsChangedEventArgsDescriptionMetadata.b(a);
            a.ae("GridSelectedCellsChangedEventArgs", () => new GridSelectedCellsChangedEventArgsDescription());
            a.ad("GridSelectedCellsChangedEventArgs", GridSelectedCellsChangedEventArgsDescriptionMetadata.a);
        }
    }
    GridSelectedCellsChangedEventArgsDescriptionMetadata.$t = markType(GridSelectedCellsChangedEventArgsDescriptionMetadata, 'GridSelectedCellsChangedEventArgsDescriptionMetadata');
    GridSelectedCellsChangedEventArgsDescriptionMetadata.a = null;
    return GridSelectedCellsChangedEventArgsDescriptionMetadata;
})();
